diff include/SDL_video.h @ 1912:8d384b647307

Setting up the OpenGL support
author Sam Lantinga <slouken@libsdl.org>
date Sun, 16 Jul 2006 09:34:01 +0000
parents 06c27a737b7a
children 8a162bfdc838
line wrap: on
line diff
--- a/include/SDL_video.h	Sun Jul 16 03:35:44 2006 +0000
+++ b/include/SDL_video.h	Sun Jul 16 09:34:01 2006 +0000
@@ -1499,6 +1499,10 @@
  *
  * \brief Set the swap interval for the current OpenGL context.
  *
+ * \param interval 0 for immediate updates, 1 for updates synchronized with the vertical retrace
+ *
+ * \return 0 on success, or -1 if setting the swap interval is not supported.
+ *
  * \sa SDL_GL_GetSwapInterval()
  */
 extern DECLSPEC int SDLCALL SDL_GL_SetSwapInterval(int interval);
@@ -1508,16 +1512,18 @@
  *
  * \brief Get the swap interval for the current OpenGL context.
  *
+ * \return 0 if there is no vertical retrace synchronization, 1 if the buffer swap is synchronized with the vertical retrace, and -1 if getting the swap interval is not supported.
+ *
  * \sa SDL_GL_SetSwapInterval()
  */
 extern DECLSPEC int SDLCALL SDL_GL_GetSwapInterval(void);
 
 /**
- * \fn void SDL_GL_SwapBuffers(void)
+ * \fn void SDL_GL_SwapWindow(SDL_WindowID windowID)
  *
  * Swap the OpenGL buffers, if double-buffering is supported.
  */
-extern DECLSPEC void SDLCALL SDL_GL_SwapBuffers(void);
+extern DECLSPEC void SDLCALL SDL_GL_SwapWindow(SDL_WindowID windowID);
 
 /**
  * \fn void SDL_GL_DeleteContext(SDL_GLContext context)
@@ -1508,16 +1512,18 @@
  *
- * Swap the OpenGL buffers, if double-buffering is supported.
+ * \brief Swap the OpenGL buffers for the window, if double-buffering is supported.
  */